# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Dict, List, Mapping, Optional, Tuple, Union
from .. import _utilities, _tables

__all__ = [
    'VaultNotification',
]

@pulumi.output_type
class VaultNotification(dict):
    def __init__(__self__, *,
                 events: List[str],
                 sns_topic: str):
        """
        :param List[str] events: You can configure a vault to publish a notification for `ArchiveRetrievalCompleted` and `InventoryRetrievalCompleted` events.
        :param str sns_topic: The SNS Topic ARN.
        """
        pulumi.set(__self__, "events", events)
        pulumi.set(__self__, "sns_topic", sns_topic)

    @property
    @pulumi.getter
    def events(self) -> List[str]:
        """
        You can configure a vault to publish a notification for `ArchiveRetrievalCompleted` and `InventoryRetrievalCompleted` events.
        """
        return pulumi.get(self, "events")

    @property
    @pulumi.getter(name="snsTopic")
    def sns_topic(self) -> str:
        """
        The SNS Topic ARN.
        """
        return pulumi.get(self, "sns_topic")

    def _translate_property(self, prop):
        return _tables.CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop


